@@ -18,14 +18,11 @@ from typing import Any
 from BaseUtils import get_archipelago_json
 GAME_NAME, AUTHOR, AP_VERSION, WORLD_VERSION = get_archipelago_json("dk64")
 
-from BaseClasses import Location, LocationProgressType
-from worlds.dk64.ap_version import version as ap_version
-
 baseclasses_loaded = False
 try:
-    from BaseClasses import Item, MultiWorld, Tutorial, ItemClassification, CollectionState
+    # DO NOT DO IMPORTS FOR AP BEFORE THIS OR IN THIS BLOCK
+    # THIS BLOCK JUST DETERMINES IF AP IS INSTALLED
     import BaseClasses
-    import settings
 
     baseclasses_loaded = True
 except ImportError:
@@ -116,6 +113,10 @@ if baseclasses_loaded:
 
     sys.path.append("worlds/dk64/")
     sys.path.append("worlds/dk64/archipelago/")
+    from BaseClasses import Item, MultiWorld, Tutorial, ItemClassification, CollectionState
+    from BaseClasses import Location, LocationProgressType
+    from worlds.dk64.ap_version import version as ap_version
+    import settings
 
     import randomizer.ItemPool as DK64RItemPool
 
@@ -819,6 +820,9 @@ if baseclasses_loaded:
                                     DK64RItems.IceTrapIceFloorGB,
                                     DK64RItems.IceTrapPaperGB,
                                     DK64RItems.IceTrapSlipGB,
+                                    DK64RItems.IceTrapAnimalGB,
+                                    DK64RItems.IceTrapRockfallGB,
+                                    DK64RItems.IceTrapDisableTagGB,
                                 ]:
                                     local_trap_count += 1
 
@@ -883,25 +887,25 @@ if baseclasses_loaded:
                     else:
                         instruments = []
                     hinted_slams = []
-                    if DK64RItems.ProgressiveSlam in self.foreignMicroHints.keys() and DK64RItems.ProgressiveSlam in self.spoiler.microhints:
+                    if DK64RItems.ProgressiveSlam in self.foreignMicroHints.keys() and DK64RItem.ItemList[DK64RItems.ProgressiveSlam].name in self.spoiler.microhints.keys():
                         # Break down the slam hint to retrieve raw data
                         text1 = "Ladies and Gentlemen! It appears that one fighter has come unequipped to properly handle this reptilian beast. Perhaps they should have looked in "
-                        hinted_slams = self.spoiler.microhints[DK64RItems.ProgressiveSlam].replace(text1, "")
-                        hinted_slams.replace(" for the elusive slam.", "")
-                        hinted_slams.split(" or ")
+                        local_hinted_slams = self.spoiler.microhints[DK64RItem.ItemList[DK64RItems.ProgressiveSlam].name].replace(text1.upper(), "")
+                        local_hinted_slams = local_hinted_slams.replace(" for the elusive slam.".upper(), "")
+                        hinted_slams = local_hinted_slams.split(" or ".upper())
                     for hintedItem in self.foreignMicroHints.keys():
                         text = ""
                         if hintedItem in helm_prog_items and self.options.microhints.value in [1, 2]:
-                            text = f"\x07{self.foreignMicroHints[hintedItem][0]}\x07 would be better off looking in \x07{self.foreignMicroHints[hintedItem][1]}\x07 for this.".upper()
+                            text = f"\x07{self.foreignMicroHints[hintedItem][0][0]}\x07 would be better off looking in \x07{self.foreignMicroHints[hintedItem][0][1]}\x07 for this.".upper()
                         elif hintedItem in instruments and self.options.microhints.value == 2:
-                            text = f"\x07{self.foreignMicroHints[hintedItem][0]}\x07 would be better off looking in \x07{self.foreignMicroHints[hintedItem][1]}\x07 for this.".upper()
+                            text = f"\x07{self.foreignMicroHints[hintedItem][0][0]}\x07 would be better off looking in \x07{self.foreignMicroHints[hintedItem][0][1]}\x07 for this.".upper()
                         elif hintedItem == DK64RItems.ProgressiveSlam:
                             for slam in self.foreignMicroHints[DK64RItems.ProgressiveSlam]:
                                 hinted_slams.append(f"\x07{slam[0]}: {slam[1]}\x07")
                             slam_text = " or ".join(hinted_slams)
                             text = f"Ladies and Gentlemen! It appears that one fighter has come unequipped to properly handle this reptilian beast. Perhaps they should have looked in {slam_text} for the elusive slam.".upper()
                         elif self.options.shopkeeper_hints.value and hintedItem in shopkeepers:
-                            text = f"{hintedItem.name} has gone on a space mission to \x07{self.foreignMicroHints[hintedItem][0]}'s\x07 \x0d{self.foreignMicroHints[hintedItem][1]}\x0d.".upper()
+                            text = f"{hintedItem.name} has gone on a space mission to \x07{self.foreignMicroHints[hintedItem][0][0]}'s\x07 \x0d{self.foreignMicroHints[hintedItem][0][1]}\x0d.".upper()
 
                         # Only create microhint if we have text to display
                         if text:
@@ -1048,9 +1052,9 @@ if baseclasses_loaded:
                     if (microhints_enabled or shopkeepers_enabled) and is_microhintable:
                         if player != loc.player:
                             if microHintItemNames[loc.item.name] in autoworld.foreignMicroHints.keys():
-                                autoworld.foreignMicroHints[microHintItemNames[loc.item.name]].append([multiworld.get_player_name(loc.player), loc.name[:80]])
+                                autoworld.foreignMicroHints[microHintItemNames[loc.item.name]].append((multiworld.get_player_name(loc.player), loc.name[:80]))
                             else:
-                                autoworld.foreignMicroHints[microHintItemNames[loc.item.name]] = [multiworld.get_player_name(loc.player), loc.name[:80]]
+                                autoworld.foreignMicroHints[microHintItemNames[loc.item.name]] = [(multiworld.get_player_name(loc.player), loc.name[:80])]
 
                     # Bail if hints are disabled at this point
                     if (is_donk_item and autoworld.options.hint_style == 0) and not is_donk_location:
