@@ -120,6 +120,9 @@ class IceTrapHandler:
         "icefloor": 0x049,  # TRANSFER_ITEM_FAKEITEM_ICEFLOOR
         "paper": 0x04A,  # TRANSFER_ITEM_FAKEITEM_PAPER
         "slip": 0x04B,  # TRANSFER_ITEM_FAKEITEM_SLIP
+        "animal": 0x04C,  # TRANSFER_ITEM_FAKEITEM_ANIMAL
+        "rockfall": 0x04D,  # TRANSFER_ITEM_FAKEITEM_ROCKFALL
+        "disabletag": 0x04E,  # TRANSFER_ITEM_FAKEITEM_DISABLETAG
     }
 
     @classmethod
@@ -1704,7 +1707,7 @@ class DK64Context(CommonContext):
                 await asyncio.sleep(1.0)
 
 
-def launch(server_address: str = None, slot_name: str = None, password: str = None, ready_callback=None, error_callback=None):
+def launch(server_address: str = None, password: str = None, ready_callback=None, error_callback=None):
     """
     Launch the client
     """
@@ -1749,9 +1752,9 @@ def launch(server_address: str = None, slot_name: str = None, password: str = No
             error_callback()
 
 
-def main(server_address: str = None, slot_name: str = None, password: str = None, ready_callback=None, error_callback=None):
+def main(server_address: str = None, password: str = None, ready_callback=None, error_callback=None):
     """Main entry point for integration with MultiWorld system"""
-    launch(server_address, slot_name, password, ready_callback, error_callback)
+    launch(server_address, password, ready_callback, error_callback)
 
 
 if __name__ == "__main__":
