@@ -668,7 +668,7 @@ class LogicVarHolder:
                         self._recalculateBlueprints()
                     if corresponding_item_id >= Items.JapesDonkeyHint and corresponding_item_id <= Items.CastleChunkyHint:
                         self.Hints.append(corresponding_item_id)
-                    if corresponding_item_id >= Items.PhotoBat and corresponding_item_id <= Items.PhotoBug:
+                    if (corresponding_item_id >= Items.PhotoBat and corresponding_item_id <= Items.PhotoBug) or (corresponding_item_id >= Items.PhotoBFI and corresponding_item_id <= Items.PhotoSeal):
                         self.Photos[corresponding_item_id] = 1
 
     def RemoveArchipelagoItem(self, ap_item):
@@ -887,6 +887,12 @@ class LogicVarHolder:
             Items.PhotoBug,
             Items.PhotoKop,
             Items.PhotoTomato,
+            Items.PhotoBFI,
+            Items.PhotoIceTomato,
+            Items.PhotoMermaid,
+            Items.PhotoLlama,
+            Items.PhotoMechfish,
+            Items.PhotoSeal,
         ]
         self.Photos = {x: item_counts[x] for x in photo_subjects}
 
@@ -1299,7 +1305,7 @@ class LogicVarHolder:
 
     def CanFreeLanky(self):
         """Check if kong at Lanky location can be freed."""
-        return self.spoiler.LocationList[Locations.LankyKong].item == Items.NoItem or self.hasMoveSwitchsanity(Switches.AztecLlamaPuzzle)
+        return (self.swim and self.hasMoveSwitchsanity(Switches.AztecLlamaPuzzle)) or self.CanPhase() or self.CanPhaseswim()
 
     def CanFreeChunky(self):
         """Check if kong at Chunky location can be freed."""
@@ -1679,6 +1685,8 @@ class LogicVarHolder:
         elif self.settings.win_condition_item == WinConditionComplex.krools_challenge:
             # Krool's Challenge: Beat K. Rool + collect all Keys, Blueprints, Bosses, and Bonus Barrels
             return Events.KRoolDefeated in self.Events and self.ItemCheck(BarrierItems.Key, 8) and self.ItemCheck(BarrierItems.Blueprint, 40) and self.bosses_beaten >= 7 and self.bonuses_beaten >= 43
+        elif self.settings.win_condition_item == WinConditionComplex.kill_the_rabbit:
+            return Events.KilledRabbit in self.Events
         elif self.settings.win_condition_item == WinConditionComplex.req_bosses:
             return self.bosses_beaten >= self.settings.win_condition_count
         elif self.settings.win_condition_item == WinConditionComplex.req_bonuses:
@@ -1715,6 +1723,11 @@ class LogicVarHolder:
         required_level_order = max(2, min(ceil(self.settings.rareware_gb_fairies / 2), 5))  # At least level 2 to give space for fairy placements, at most level 5 to allow shenanigans
         return have_enough_fairies and is_correct_kong and self.HasFillRequirementsForLevel(self.settings.level_order[required_level_order])
 
+    def CanGetBlueprintReward(self, value):
+        """Check if you have sufficient access to a Blueprint reward location."""
+        # Archipelago keeps it simple - no need for a buffer
+        return self.BlueprintsWithKong >= value
+
     def CanSurviveFallDamage(self):
         """Check if you can survive a single instance of fall damage."""
         if self.settings.damage_amount != DamageAmount.ohko:
