@@ -122,6 +122,8 @@ ShufflableExits = {
     Transitions.FactoryPowerToChunkyRoom: ShufflableExit("Frantic Factory Power Room to Chunky Room", Regions.PowerHut, TransitionBack(Regions.ChunkyRoomPlatform, "From Power Shed", "Frantic Factory Main from Power Shed", Transitions.FactoryChunkyRoomToPower)),
     Transitions.FactoryLowerCoreToInsideCore: ShufflableExit("Frantic Factory Main to Crusher Room", Regions.LowerCore, TransitionBack(Regions.InsideCore, "From Factory Main", "Frantic Factory Crusher Room", Transitions.FactoryInsideCoreToLowerCore), ExitCategories.FactoryExterior, regionKongs={Kongs.donkey, Kongs.lanky}),
     Transitions.FactoryInsideCoreToLowerCore: ShufflableExit("Frantic Factory Crusher Room to Main", Regions.InsideCore, TransitionBack(Regions.LowerCore, "From Crusher Room", "Frantic Factory Main from Crusher Room", Transitions.FactoryLowerCoreToInsideCore)),
+    Transitions.FactoryStorageToArcade: ShufflableExit("Frantic Factory Storage to Arcade", Regions.BeyondHatch, TransitionBack(Regions.FactoryArcadeTunnel, "From Tiny BP Area (To Arcade Area)", "Frantic Factory Arcade from Storage", Transitions.FactoryArcadeToStorage), ExitCategories.FactoryExterior, move=True),
+    Transitions.FactoryArcadeToStorage: ShufflableExit("Frantic Factory Arcade to Storage", Regions.FactoryArcadeTunnel, TransitionBack(Regions.BeyondHatch, "From Arcade Area (near Tiny BP)", "Frantic Factory Storage from Arcade", Transitions.FactoryStorageToArcade), ExitCategories.FactoryExterior),
     # Transitions.FactoryMainToBBlast: ShufflableExit("Frantic Factory Main to BBlast", Regions.BeyondHatch, TransitionBack(Regions.FactoryBaboonBlast, "From Factory Main", "Frantic Factory Baboon Blast"), ExitCategories.FactoryExterior, entryKongs={Kongs.donkey}, regionKongs={Kongs.donkey}, move=True),
 
     # Gloomy Galleon Exits
